==> net.bluemind.p2.platform-4.9.3879.zip: net/bluemind/todolist/api/gwt/serder/VTodoChangesItemModifyGwtSerDer.java <==
/* BEGIN LICENSE
 * Copyright Â© Blue Mind SAS, 2012-2016
 *
 * This file is part of BlueMind. BlueMind is a messaging and collaborative
 * solution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of either the GNU Affero General Public License as
 * published by the Free Software Foundation (version 3 of the License).
 *
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See LICENSE.txt
 * END LICENSE
 */
package net.bluemind.todolist.api.gwt.serder;

import net.bluemind.core.commons.gwt.GwtSerDer;
import net.bluemind.core.commons.gwt.GwtSerDerUtils;

import com.google.gwt.json.client.JSONObject;
import com.google.gwt.json.client.JSONValue;

public class VTodoChangesItemModifyGwtSerDer implements GwtSerDer<net.bluemind.todolist.api.VTodoChanges.ItemModify> {

	public VTodoChangesItemModifyGwtSerDer( ) {
	}

	@Override
	public net.bluemind.todolist.api.VTodoChanges.ItemModify deserialize(JSONValue value) {
		if( value == null ) {
			return null;
		}

		JSONObject json = value.isObject();
		if (json == null) {
			return null;
		}

		net.bluemind.todolist.api.VTodoChanges.ItemModify ret = new net.bluemind.todolist.api.VTodoChanges.ItemModify();
		deserializeTo(ret, json);

		return ret;
	}

	public void deserializeTo(net.bluemind.todolist.api.VTodoChanges.ItemModify ret, JSONObject json) {

		JSONValue uidJSON = json.get("uid");
		ret.uid =  GwtSerDerUtils.STRING.deserialize(uidJSON);
		JSONValue versionJSON = json.get("version");
		ret.version =  GwtSerDerUtils.LONG.deserialize(versionJSON);
		JSONValue valueJSON = json.get("value");
		ret.value =  new net.bluemind.todolist.api.gwt.serder.VTodoGwtSerDer().deserialize(valueJSON);
		JSONValue sendNotificationJSON = json.get("sendNotification");
		ret.sendNotification =  GwtSerDerUtils.BOOLEAN.deserialize(sendNotificationJSON);
	}

	@Override
	public JSONValue serialize(net.bluemind.todolist.api.VTodoChanges.ItemModify o) {
		if (o == null) {
			return null;
		}

		JSONObject ret = new JSONObject();
		serializeTo( o, ret);
		return ret;
	}

	public void serializeTo(net.bluemind.todolist.api.VTodoChanges.ItemModify o, JSONObject ret) {

		ret.put("uid",  GwtSerDerUtils.STRING.serialize( o.uid ));
		ret.put("version",  GwtSerDerUtils.LONG.serialize( o.version ));
		ret.put("value",  new net.bluemind.todolist.api.gwt.serder.VTodoGwtSerDer().serialize( o.value ));
		ret.put("sendNotification",  GwtSerDerUtils.BOOLEAN.serialize( o.sendNotification ));
	}
}

==> net.bluemind.p2.platform-5.5.3184.zip: net/bluemind/todolist/api/gwt/serder/VTodoChangesItemModifyGwtSerDer.java <==
/* BEGIN LICENSE
 * Copyright Â© Blue Mind SAS, 2012-2016
 *
 * This file is part of BlueMind. BlueMind is a messaging and collaborative
 * solution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of either the GNU Affero General Public License as
 * published by the Free Software Foundation (version 3 of the License).
 *
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See LICENSE.txt
 * END LICENSE
 */
package net.bluemind.todolist.api.gwt.serder;

import java.util.Set;
import java.util.HashSet;

import net.bluemind.core.commons.gwt.GwtSerDer;
import net.bluemind.core.commons.gwt.GwtSerDerUtils;

import com.google.gwt.json.client.JSONObject;
import com.google.gwt.json.client.JSONValue;

public class VTodoChangesItemModifyGwtSerDer implements GwtSerDer<net.bluemind.todolist.api.VTodoChanges.ItemModify> {

	public VTodoChangesItemModifyGwtSerDer( ) {
	}

	@Override
	public net.bluemind.todolist.api.VTodoChanges.ItemModify deserialize(JSONValue value) {
		if( value == null ) {
			return null;
		}

		JSONObject json = value.isObject();
		if (json == null) {
			return null;
		}

		net.bluemind.todolist.api.VTodoChanges.ItemModify ret = new net.bluemind.todolist.api.VTodoChanges.ItemModify();
		deserializeTo(ret, json);
		return ret;
	}

	public void deserializeTo(net.bluemind.todolist.api.VTodoChanges.ItemModify ret, JSONObject json) {
		JSONValue uidJSON = json.get("uid");
		ret.uid =  GwtSerDerUtils.STRING.deserialize(uidJSON);
		JSONValue versionJSON = json.get("version");
		ret.version =  GwtSerDerUtils.LONG.deserialize(versionJSON);
		JSONValue valueJSON = json.get("value");
		ret.value =  new net.bluemind.todolist.api.gwt.serder.VTodoGwtSerDer().deserialize(valueJSON);
		JSONValue sendNotificationJSON = json.get("sendNotification");
		ret.sendNotification =  GwtSerDerUtils.BOOLEAN.deserialize(sendNotificationJSON);
	}

	public void deserializeTo(net.bluemind.todolist.api.VTodoChanges.ItemModify ret, JSONObject json, Set<String> childPropertiesToIgnore) {
		if (!childPropertiesToIgnore.contains("uid")) {
			JSONValue uidJSON = json.get("uid");
			ret.uid =  GwtSerDerUtils.STRING.deserialize(uidJSON);
		}
		if (!childPropertiesToIgnore.contains("version")) {
			JSONValue versionJSON = json.get("version");
			ret.version =  GwtSerDerUtils.LONG.deserialize(versionJSON);
		}
		if (!childPropertiesToIgnore.contains("value")) {
			JSONValue valueJSON = json.get("value");
			ret.value =  new net.bluemind.todolist.api.gwt.serder.VTodoGwtSerDer().deserialize(valueJSON);
		}
		if (!childPropertiesToIgnore.contains("sendNotification")) {
			JSONValue sendNotificationJSON = json.get("sendNotification");
			ret.sendNotification =  GwtSerDerUtils.BOOLEAN.deserialize(sendNotificationJSON);
		}
	}


	@Override
	public JSONValue serialize(net.bluemind.todolist.api.VTodoChanges.ItemModify o) {
		if (o == null) {
			return null;
		}

		JSONObject ret = new JSONObject();
		serializeTo( o, ret);
		return ret;
	}

	public void serializeTo(net.bluemind.todolist.api.VTodoChanges.ItemModify o, JSONObject ret) {

		ret.put("uid",  GwtSerDerUtils.STRING.serialize( o.uid ));
		ret.put("version",  GwtSerDerUtils.LONG.serialize( o.version ));
		ret.put("value",  new net.bluemind.todolist.api.gwt.serder.VTodoGwtSerDer().serialize( o.value ));
		ret.put("sendNotification",  GwtSerDerUtils.BOOLEAN.serialize( o.sendNotification ));
	}

	public void serializeTo(net.bluemind.todolist.api.VTodoChanges.ItemModify o, JSONObject ret, Set<String> childPropertiesToIgnore) {

		if (!childPropertiesToIgnore.contains("uid")) {
			ret.put("uid",  GwtSerDerUtils.STRING.serialize( o.uid ));
		}
		if (!childPropertiesToIgnore.contains("version")) {
			ret.put("version",  GwtSerDerUtils.LONG.serialize( o.version ));
		}
		if (!childPropertiesToIgnore.contains("value")) {
			ret.put("value",  new net.bluemind.todolist.api.gwt.serder.VTodoGwtSerDer().serialize( o.value ));
		}
		if (!childPropertiesToIgnore.contains("sendNotification")) {
			ret.put("sendNotification",  GwtSerDerUtils.BOOLEAN.serialize( o.sendNotification ));
		}
	}


	public Set<String> propertiesToIgnore() {
		return new HashSet<>();
	}
}
